@@ -4,7 +4,7 @@ from .utils import func_logger, format_hctl, ScsiCommandFailed
 from .scsi import scsi_host_scan, scsi_add_single_device, scsi_remove_single_device, remove_device_via_sysfs
 from .scsi import do_report_luns, do_standard_inquiry, do_test_unit_ready
 from .getters import is_device_exist, get_scsi_generic_device
-from .getters import get_channels, get_targets, get_luns
+from .getters import get_hosts, get_channels, get_targets, get_luns
 from .getters import is_there_a_bug_in_target_removal, is_there_a_bug_in_sysfs_async_scanning
 
 logger = getLogger(__name__)
@@ -100,6 +100,6 @@ def rescan_scsi_host(host):
                 logger.exception(msg.format(host, channel, target))
 
 @func_logger
-def rescan_scsi_hosts(host_numbers):
-    for host_number in host_numbers:
+def rescan_scsi_hosts():
+    for host_number in get_hosts():
         rescan_scsi_host(host_number)
